==> cuda-13.0.2-1-x86_64.pkg.tar.zst: opt/cuda/targets/x86_64-linux/include/cccl/cuda/std/__fwd/string_view.h <==
// -*- C++ -*-
//===---------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES.
//
//===---------------------------------------------------------------------===//

#ifndef _LIBCUDACXX___FWD_STRING_VIEW_H
#define _LIBCUDACXX___FWD_STRING_VIEW_H

#include <cuda/std/detail/__config>

#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
#  pragma GCC system_header
#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
#  pragma clang system_header
#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
#  pragma system_header
#endif // no system header

#include <cuda/std/__fwd/string.h>

_LIBCUDACXX_BEGIN_NAMESPACE_STD

template <class _CharT, class _Traits = char_traits<_CharT>>
class _CCCL_TYPE_VISIBILITY_DEFAULT basic_string_view;

using string_view = basic_string_view<char>;
#if _LIBCUDACXX_HAS_CHAR8_T()
using u8string_view = basic_string_view<char8_t>;
#endif // _LIBCUDACXX_HAS_CHAR8_T()
using u16string_view = basic_string_view<char16_t>;
using u32string_view = basic_string_view<char32_t>;
#ifndef _LIBCUDACXX_HAS_NO_WIDE_CHARACTERS
using wstring_view = basic_string_view<wchar_t>;
#endif

// clang-format off
template <class _CharT, class _Traits>
class _LIBCUDACXX_PREFERRED_NAME(string_view)
#ifndef _LIBCUDACXX_HAS_NO_WIDE_CHARACTERS
      _LIBCUDACXX_PREFERRED_NAME(wstring_view)
#endif
#if _LIBCUDACXX_HAS_CHAR8_T()
      _LIBCUDACXX_PREFERRED_NAME(u8string_view)
#endif // _LIBCUDACXX_HAS_CHAR8_T()
      _LIBCUDACXX_PREFERRED_NAME(u16string_view)
      _LIBCUDACXX_PREFERRED_NAME(u32string_view)
      basic_string_view;
// clang-format on
_LIBCUDACXX_END_NAMESPACE_STD

#endif // _LIBCUDACXX___FWD_STRING_VIEW_H

==> cuda-13.1.0-1-x86_64.pkg.tar.zst: opt/cuda/targets/x86_64-linux/include/cccl/cuda/std/__fwd/string_view.h <==
//===----------------------------------------------------------------------===//
//
// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2025 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//

#ifndef _LIBCUDACXX___FWD_STRING_VIEW_H
#define _LIBCUDACXX___FWD_STRING_VIEW_H

#include <cuda/std/detail/__config>

#if defined(_CCCL_IMPLICIT_SYSTEM_HEADER_GCC)
#  pragma GCC system_header
#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_CLANG)
#  pragma clang system_header
#elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
#  pragma system_header
#endif // no system header

#include <cuda/std/__fwd/char_traits.h>

#include <cuda/std/__cccl/prologue.h>

_LIBCUDACXX_BEGIN_NAMESPACE_STD

template <class _CharT, class _Traits = char_traits<_CharT>>
class _CCCL_TYPE_VISIBILITY_DEFAULT basic_string_view;

using string_view = basic_string_view<char>;
#if _CCCL_HAS_CHAR8_T()
using u8string_view = basic_string_view<char8_t>;
#endif // _CCCL_HAS_CHAR8_T()
using u16string_view = basic_string_view<char16_t>;
using u32string_view = basic_string_view<char32_t>;
#if _CCCL_HAS_WCHAR_T()
using wstring_view = basic_string_view<wchar_t>;
#endif // _CCCL_HAS_WCHAR_T()

// clang-format off
template <class _CharT, class _Traits>
class _CCCL_PREFERRED_NAME(string_view)
#if _CCCL_HAS_CHAR8_T()
_CCCL_PREFERRED_NAME(u8string_view)
#endif // _CCCL_HAS_CHAR8_T()
_CCCL_PREFERRED_NAME(u16string_view)
_CCCL_PREFERRED_NAME(u32string_view)
#if _CCCL_HAS_WCHAR_T()
_CCCL_PREFERRED_NAME(wstring_view)
#endif // _CCCL_HAS_WCHAR_T()
      basic_string_view;
// clang-format on
_LIBCUDACXX_END_NAMESPACE_STD

#include <cuda/std/__cccl/epilogue.h>

#endif // _LIBCUDACXX___FWD_STRING_VIEW_H
